@@ -73,7 +73,7 @@ G_BEGIN_DECLS
 
 typedef enum {
 	/* If you add new items here or reorder them, you have to update the
-	   .etspec files for the tables using this model */
+	 * .etspec files for the tables using this model */
 	E_CAL_MODEL_FIELD_CATEGORIES,
 	E_CAL_MODEL_FIELD_CLASSIFICATION,
 	E_CAL_MODEL_FIELD_COLOR,            /* not a real field */
@@ -281,7 +281,8 @@ ECalModelComponent *
 						 const ECalComponentId *id);
 gchar *		e_cal_model_date_value_to_string (ECalModel *model,
 						 gconstpointer value);
-void		e_cal_model_generate_instances	(ECalModel *model,
+void		e_cal_model_generate_instances_sync
+						(ECalModel *model,
 						 time_t start,
 						 time_t end,
 						 ECalRecurInstanceFn cb,
